==> PPDF_1_0.zip: PubMedPDF/auto_run.php <==
<?php
	include("../../mainfile.php");
	include (XOOPS_ROOT_PATH."/header.php");
	
	## Proxy
	if($xoopsModuleConfig['proxy']){
		include (XOOPS_ROOT_PATH."/class/snoopy.php");
		$proxy = new Snoopy;
		$proxy->read_timeout = 0;
		$proxy->proxy_host = $xoopsModuleConfig['proxy_url'];
		$proxy->proxy_port = $xoopsModuleConfig['proxy_port'];
	}else{
		$proxy = 0;
	}
	($xoopsUser) ? $user = $xoopsUser->uname() : $user="guest";

	Auto_run($xoopsModuleConfig['updir'], $proxy, $user);


# Auto_run($upload dir, $proxy config, $user)

function Auto_run($dir, $proxy, $user){

	require "include/pubmed.php";
	require "include/db.php";
	require "include/conn.php";
	$count = 0;
	
  if( $handle = opendir( $dir ) ){
    while ( false !== $file = readdir( $handle ) ){
      if( $file != "." && $file != ".." ){
        if( substr($file,-4) == ".pdf"){
        	
        	$PMID = substr($file,0,-4);
        	echo "[".$PMID."] ";
					
					#check PMID
					$sql = "SELECT * FROM ".$T_ID." WHERE PMID='".$PMID."'";
					$res = mysql_query($sql, $conn);
					if(mysql_num_rows($res) != 0){
						echo "already registered.<br>";

					}else{
						if($count > 70){
							for($i=0;$i<10000;$i++);
							$count = 0;
						}					
					
						if(file_exists("pubmed_xml/$PMID.xml")){
							$pm_data = PubMedByFile( $PMID, 'pubmed_xml/', 0 );
   	  				echo $pm_data[t]."<br>";
							DB($pm_data, $user);

						}elseif(file_exists("search_xml/$PMID.xml")){
							$pm_data = PubMedByFile( $PMID, 'search_xml/', 0 );
   	  				echo $pm_data[t]."<br>";
							DB($pm_data, $user);
							rename( "search_xml/$PMID.xml", "pubmed_xml/$PMID.xml" );

						}else{
			       	if(!$pm_data = PubMed($PMID, $proxy, 'pubmed_xml/')){
								echo "id missing...<br>";
	 		      	}else{
	     		  		echo $pm_data[t]."<br>";
								DB($pm_data, $user);
    			   	}
    	   			$count ++;
						}
        	}
				}
			}
		}
	closedir( $handle );
	}
	return;
}

	include (XOOPS_ROOT_PATH."/footer.php");
?>

==> PPDF_1_3_1.zip: PubMedPDF/auto_run.php <==
<?php
	include("../../mainfile.php");
	include (XOOPS_ROOT_PATH."/header.php");
	
	## Proxy
	include (XOOPS_ROOT_PATH."/class/snoopy.php");
	if($xoopsModuleConfig['proxy']){
		$proxy = new Snoopy;
		$proxy->read_timeout = 0;
		$proxy->proxy_host = $xoopsModuleConfig['proxy_url'];
		$proxy->proxy_port = $xoopsModuleConfig['proxy_port'];
	}else{
		$proxy = 0;
		$snoopy = new Snoopy;
	}
	($xoopsUser) ? $user = $xoopsUser->uname() : $user="guest";

	Auto_run($xoopsModuleConfig['updir'], $proxy, $snoopy, $user);


# Auto_run($upload dir, $proxy_config, $snoopy, $user)

function Auto_run($dir, $proxy, $snoopy, $user){

	require "include/pubmed.php";
	require "include/db.php";
	require "include/conn.php";
	$count = 0;
	
  if( $handle = opendir( $dir ) ){
    while ( false !== $file = readdir( $handle ) ){
      if( $file != "." && $file != ".." ){
        if( substr($file,-4) == ".pdf"){
        	
        	$PMID = substr($file,0,-4);
        	#echo "[".$PMID."] ";
					
					#check PMID
					$sql = "SELECT * FROM ".$T_ID." WHERE PMID='".$PMID."'";
					$res = mysql_query($sql, $conn);
					if(mysql_num_rows($res) != 0){
					#	echo "already registered.<br>";

					}else{
						if($count > 70){
							for($i=0;$i<10000;$i++);
							$count = 0;
						}					
					
						if(file_exists("pubmed_xml/$PMID.xml")){
							$pm_data = PubMedByFile( $PMID, 'pubmed_xml/', 0 );
   	  				echo $pm_data[t]."<br>";
							DB($pm_data, $user);

						}elseif(file_exists("search_xml/$PMID.xml")){
							$pm_data = PubMedByFile( $PMID, 'search_xml/', 0 );
   	  				echo $pm_data[t]."<br>";
							DB($pm_data, $user);
							rename( "search_xml/$PMID.xml", "pubmed_xml/$PMID.xml" );

						}else{
			       	if(!$pm_data = PubMed($PMID, $proxy, $snoopy, 'pubmed_xml/')){
							#	echo "id missing...<br>";
	 		      	}else{
	     		  		echo $pm_data[t]."<br>";
								DB($pm_data, $user);
    			   	}
    	   			$count ++;
						}
        	}
				}
			}
		}
	closedir( $handle );
	}
	return;
}

	include (XOOPS_ROOT_PATH."/footer.php");
?>
